@@ -7,7 +7,7 @@
 #  define VTKIMAGINGSTATISTICS_NO_EXPORT
 #else
 #  ifndef VTKIMAGINGSTATISTICS_EXPORT
-#    ifdef vtkImagingStatistics_EXPORTS
+#    ifdef ImagingStatistics_EXPORTS
         /* We are building this library */
 #      define VTKIMAGINGSTATISTICS_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,15 +23,20 @@
 
 #ifndef VTKIMAGINGSTATISTICS_DEPRECATED
 #  define VTKIMAGINGSTATISTICS_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKIMAGINGSTATISTICS_DEPRECATED_EXPORT VTKIMAGINGSTATISTICS_EXPORT __attribute__ ((__deprecated__))
-#  define VTKIMAGINGSTATISTICS_DEPRECATED_NO_EXPORT VTKIMAGINGSTATISTICS_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKIMAGINGSTATISTICS_NO_DEPRECATED
+#ifndef VTKIMAGINGSTATISTICS_DEPRECATED_EXPORT
+#  define VTKIMAGINGSTATISTICS_DEPRECATED_EXPORT VTKIMAGINGSTATISTICS_EXPORT VTKIMAGINGSTATISTICS_DEPRECATED
 #endif
 
-
-
+#ifndef VTKIMAGINGSTATISTICS_DEPRECATED_NO_EXPORT
+#  define VTKIMAGINGSTATISTICS_DEPRECATED_NO_EXPORT VTKIMAGINGSTATISTICS_NO_EXPORT VTKIMAGINGSTATISTICS_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKIMAGINGSTATISTICS_NO_DEPRECATED
+#    define VTKIMAGINGSTATISTICS_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKIMAGINGSTATISTICS_EXPORT_H */
